@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: add_call_to_action_plugin.py 12295 2020-06-02 19:01:46Z Trista $
+# $Id: add_call_to_action_plugin.py 12330 2020-06-08 20:10:48Z Trista $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,14 +12,15 @@
 # limitations under the License.
 #
 # $Author: Trista $
-# $Date: 2020-06-03 04:01:46 +0900 (週三, 03 六月 2020) $
-# $Revision: 12295 $
+# $Date: 2020-06-09 05:10:48 +0900 (週二, 09 六月 2020) $
+# $Revision: 12330 $
 
 import datetime
 
 from aldryn_newsblog.models import Article, ArticleTranslation
 from cms.models.pluginmodel import CMSPlugin
 from cms.models.pagemodel import Page, TreeNode
+from cms.models.titlemodels import Title
 from djangocms_forms.models import Form, FormDefinition
 from django.conf import settings
 from django.core.management.base import BaseCommand
@@ -80,15 +81,16 @@ class Command(BaseCommand):
                         redirectPage = thankNode.all()[0].cms_pages.all()[0]
                     else:
                         
-                        thankNode = TreeNode(site_id=cmsPlugin.page.node.site_id)
+                        thankNode = TreeNode(site_id=settings.SITE_ID, depth=1)
                         lan = cmsPlugin.language
+                        thankNode.save()
                         redirectPage = Page(node=thankNode, 
                                             template=_settings.THANK_DEFAULT_TEMPLATE, 
-                                            created_by=request.user, 
+                                            created_by='script', 
                                             languages=lan)
                         redirectPage.save()
                         pageTitle = Title(language=lan, title='Thank', slug='thank', page=redirectPage, 
-                                           path=f'{obj.page.title_set.all()[0].path}/thank')
+                                           path='thank')
                         pageTitle.save()
                         redirectPage.publish(language=lan)
 
