@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 12125 2020-04-26 15:56:49Z Lavender $
+# $Id: setup.py 12609 2020-11-12 18:17:22Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-04-26 23:56:49 +0800 (Sun, 26 Apr 2020) $
-# $Revision: 12125 $
+# $Date: 2020-11-13 03:17:22 +0900 (週五, 13 十一月 2020) $
+# $Revision: 12609 $
 
 import re
 import os
@@ -59,9 +59,9 @@ logger.addHandler(handler)
 
 INTRODUCTION_URL = "https://www.django-cms-themes.com/static/docs"
 SETUP_URL = "https://www.django-cms-themes.com/static/product/assets/setup.py"
-SETUP_VERSION = "1.1.0"
+SETUP_VERSION = "1.1.1"
 SETUP_DIR = os.path.dirname(os.path.abspath(__file__))
-SETUP_SUPPORTED_CMS_VERSION = "3.7.1"
+SETUP_SUPPORTED_CMS_VERSION = "3.7.4"
 CKEDITOR_SETTINGS = \
 '''
 CKEDITOR_SETTINGS = {
@@ -216,6 +216,8 @@ if not sys.version_info.major == 3:
     sys.exit(1)
 
 def copyToPath(baseDir, templateDir, staticDir, mode):
+    import django
+    
     if not templateDir:
         templateDir = os.path.join(baseDir, 'templates')
     if not staticDir:
@@ -259,6 +261,12 @@ def copyToPath(baseDir, templateDir, staticDir, mode):
                     colored("%s exists. failed to copy file." % dst, "red"))
             else:
                 shutil.copyfile(origin, dst)
+                if django.VERSION >= (3, 0) and os.path.join(SETUP_DIR, "templates") in root:
+                    with open(dst, 'r') as t:
+                        content = t.read()
+                    content = content.replace("staticfiles", "static")
+                    with open(dst, 'w') as t:
+                        t.write(content)
                 logger.info("Succeed to copy file to %s." % dst)
    
 def findSettings(path):
@@ -484,8 +492,8 @@ if __name__ == "__main__":
         
         parser.add_argument(
             "--djangoVersion", metavar='djangoVersion', 
-            type=str,  nargs='?', default="2.2",
-            help="Django version, default is '2.2'"
+            type=str,  nargs='?', default="3.0",
+            help="Django version, default is '3.0'"
         )
         
         parser.add_argument(
@@ -525,12 +533,13 @@ if __name__ == "__main__":
         djangoVersion = args.djangoVersion
         
         djangoVersionTable = {
+            '3.0': '<3.1.0,>=3.0',
             '2.2': '<3.0.0,>=2.2',
             '1.11': '<2.0.0,>=1.11',
         }
         if not djangoVersion in djangoVersionTable:
             logger.warning(colored(
-                "Django version must be 1.11 or 2.2", "yellow"))
+                "Django version must be 1.11, 2.2 or 3.0", "yellow"))
             sys.exit(1)
         else:
             djangoVersion = djangoVersionTable[djangoVersion]
@@ -577,17 +586,16 @@ if __name__ == "__main__":
                 
             cmsVersion = data["DjangoCMSVersion"]
         else:
-            cmsVersion = '3.7.1'
+            cmsVersion = '3.7.4'
             
         # default for setup.py
-        cmsVersion = '3.7.1'
+        cmsVersion = '3.7.4'
         
         if cmsVersion.startswith("3.6"):
             installVersion = "1.2.0"
         elif cmsVersion.startswith("3.7"):
-            installVersion = "1.2.0"
+            installVersion = "1.2.3"
         else:
-            installVersion = "1.2.0"
             logger.warning(colored(
                 "Not support django-cms<3.6", "yellow"))
             sys.exit(1)
@@ -611,6 +619,29 @@ if __name__ == "__main__":
             import cms
             
         cmsVersion = cms.__version__
+        
+        # check package version
+        if django.VERSION <= (2, 0): 
+            try:
+                os.system(
+                    "pip install -U djangocms_text_ckeditor==3.8.0 --no-deps")
+                os.system(
+                    "pip install -U html5lib==1.0.1 --no-deps")
+                os.system("pip install cmsplugin-filer==1.1.3")
+            except Exception as e:
+                logger.error(
+                    colored("Can't install djangocms_text_ckeditor==3.8.0", 
+                            "red"))
+                sys.exit(1)
+        else:
+            try:
+                os.system(
+                    "pip install -U djangocms_text_ckeditor==3.10.0 --no-deps")
+            except Exception as e:
+                logger.error(
+                    colored("Can't install djangocms_text_ckeditor==3.10.0", 
+                            "red"))
+                sys.exit(1)
             
         sendLog({
             "level": "INFO",
@@ -714,28 +745,6 @@ if __name__ == "__main__":
         cmsVersion = cms.__version__.split('.')
 
         import django
-         
-        if django.VERSION <= (2, 0): 
-            try:
-                os.system(
-                    "pip install -U djangocms_text_ckeditor==3.8.0 --no-deps")
-                os.system(
-                    "pip install -U html5lib==1.0.1 --no-deps")
-                os.system("pip install cmsplugin-filer==1.1.3")
-            except Exception as e:
-                logger.error(
-                    colored("Can't install djangocms_text_ckeditor==3.8.0", 
-                            "red"))
-                sys.exit(1)
-        else:
-            try:
-                os.system(
-                    "pip install -U djangocms_text_ckeditor==3.8.0 --no-deps")
-            except Exception as e:
-                logger.error(
-                    colored("Can't install djangocms_text_ckeditor==3.8.0", 
-                            "red"))
-                sys.exit(1)
        
         django.setup()
         
