@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11946 2020-02-22 13:22:03Z Trista $
+# $Id: views.py 12026 2020-03-29 14:59:31Z Trista $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Trista $
-# $Date: 2020-02-22 21:22:03 +0800 (週六, 22 二月 2020) $
-# $Revision: 11946 $
+# $Date: 2020-03-29 23:59:31 +0900 (週日, 29 三月 2020) $
+# $Revision: 12026 $
 
 import datetime
 import logging
@@ -174,7 +174,7 @@ def sendAndRedirect(request, email, fromUrl, redirectTo, formId=None):
         errorCode = ErrorCode.EMAIL_FORMAT 
         logger.error('Email format error: %s' % str(e))
 
-    # Reditrct
+    # Redirect
     if redirectTo:     
         if six.PY3:
             url = urllib.parse.quote(redirectTo)
@@ -191,8 +191,8 @@ def sendAndRedirect(request, email, fromUrl, redirectTo, formId=None):
     if not form:
         return redirect(url)
     else:
-        if landingForm.page_redirect:
-            url = landingForm.page_redirect.get_public_url() + \
+        if landingForm.redirect_url:
+            url = landingForm.redirect_url + \
                 "?from_url=%s&error=%d" % (fromUrl, errorCode)
         return redirect(url)
     
